# ![icon](https://github.com/kokseen1/Toori/blob/master/toori/icon.png?raw=true) Toori 

[![PyPI Release](https://github.com/kokseen1/Toori/actions/workflows/release.yml/badge.svg)](https://github.com/kokseen1/Toori/actions/workflows/release.yml)
[![PyPI Version](https://img.shields.io/pypi/v/toori.svg)](https://pypi.python.org/pypi/toori/)

A minimal layer 3 tunnel over http(s).

## Prerequisites

- [MSVC Build Tools](https://visualstudio.microsoft.com/downloads/)

## Installation

```
pip install toori
```

## Usage

Run as Administrator:

```shell
toori <server address>
```

e.g.
```
toori https://toori.server
```
